@@ -1,9 +1,9 @@
 package App::instopt;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-04-03'; # DATE
+our $DATE = '2021-04-22'; # DATE
 our $DIST = 'App-instopt'; # DIST
-our $VERSION = '0.017'; # VERSION
+our $VERSION = '0.018'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -662,7 +662,6 @@ sub download {
         my $res;
 
         $res = list_downloaded_versions(%args, software=>$sw);
-        #use DD; dd $res;
         my $v0 = $res->[2] ? $res->[2]{ $args{arch} }[-1] : undef;
 
         $res = App::swcat::latest_version(%args, softwares_or_patterns=>[$sw]);
@@ -864,7 +863,7 @@ sub update {
     for my $sw (@$sws) {
         my $mod = App::swcat::_load_swcat_mod($sw);
         my $res = list_installed_versions(%args, software=>$sw);
-        my $v0 = $res->[2] ? $res->[2]{ $args{arch} }[-1] : undef;
+        my $v0 = $res->[2] ? $res->[2][-1] : undef;
 
         my $v;
         my ($filepath, $filename);
@@ -1118,7 +1117,7 @@ App::instopt - Download and install software
 
 =head1 VERSION
 
-This document describes version 0.017 of App::instopt (from Perl distribution App-instopt), released on 2021-04-03.
+This document describes version 0.018 of App::instopt (from Perl distribution App-instopt), released on 2021-04-22.
 
 =head1 SYNOPSIS
 
@@ -1540,7 +1539,7 @@ Result:
          func    => "Perinci::Access::Schemeless::action_call",
          line    => 494,
          package => "Perinci::Access::Schemeless",
-         time    => 1617422026,
+         time    => 1619056032,
          type    => "create",
        },
      ],
